# Codice di Condotta del Contributor Covenant

## Il nostro impegno

Noi, in qualità di membri, contributori e leader, ci impegniamo a rendere la partecipazione nella nostra comunità un'esperienza libera da molestie per tutti, indipendentemente dall'età, dalle dimensioni del corpo, da disabilità visibili o invisibili, dall'etnia, dalle caratteristiche sessuali, dall'identità e dall'espressione di genere, dal livello di esperienza, dall'istruzione, dallo status socio-economico, dalla nazionalità, dall'aspetto personale, dalla razza, dalla religione o dall'identità e dall'orientamento sessuale.

Ci impegniamo ad agire e interagire in modi che contribuiscono a una comunità aperta, accogliente, diversificata, inclusiva e sana.

## I nostri standard

Esempi di comportamenti che contribuiscono a un ambiente positivo per la nostra  
comunità includono:

* Dimostrare empatia e gentilezza verso gli altri  
* Essere rispettosi delle opinioni, punti di vista ed esperienze diverse  
* Offrire e accettare con grazia feedback costruttivi  
* Assumersi la responsabilità e scusarsi con coloro che sono stati colpiti dai nostri errori,  
  e imparare dall'esperienza

* Concentrarsi su ciò che è meglio non solo per noi come individui, ma per l'intera comunità

Esempi di comportamenti inaccettabili includono:

* L'uso di linguaggio o immagini a sfondo sessuale, e attenzioni o avances sessuali di qualsiasi tipo

* Commenti provocatori, insultanti o denigratori, e attacchi personali o politici
* Molestie pubbliche o private
* Pubblicazione di informazioni private altrui, come indirizzi fisici o email, senza il loro esplicito permesso

* Altri comportamenti che potrebbero ragionevolmente essere considerati inappropriati in un contesto professionale

## Responsabilità di applicazione

I leader della comunità sono responsabili di chiarire e far rispettare i nostri standard di comportamento accettabile e intraprenderanno azioni correttive appropriate ed eque in risposta a qualsiasi comportamento che ritengano inappropriato, minaccioso, offensivo o dannoso.

I leader della comunità hanno il diritto e la responsabilità di rimuovere, modificare o rifiutare commenti, commit, codice, modifiche alle wiki, issue e altri contributi che non sono allineati a questo Codice di Condotta, e comunicheranno le ragioni delle decisioni di moderazione quando opportuno.

## Ambito

Questo Codice di Condotta si applica in tutti gli spazi della comunità e si applica anche quando un individuo rappresenta ufficialmente la comunità in spazi pubblici. Esempi di rappresentanza della nostra comunità includono l'uso di un indirizzo email ufficiale, la pubblicazione tramite un account ufficiale sui social media o l'azione come rappresentante nominato in un evento online o offline.

## Applicazione

Gli episodi di comportamento abusivo, molesto o comunque inaccettabile possono essere segnalati ai leader della comunità responsabili dell'applicazione delle regole all'indirizzo aw@funstory.ai.  
Tutte le segnalazioni saranno esaminate e investigate in modo tempestivo ed equo.  

Tutti i leader della comunità sono tenuti a rispettare la privacy e la sicurezza del segnalante di qualsiasi incidente.

## Linee guida per l'applicazione

I leader della comunità seguiranno queste Linee guida sull'impatto della comunità nel determinare le conseguenze per qualsiasi azione che ritengano in violazione di questo Codice di condotta:

### 1. Correzione

**Impatto sulla comunità**: Uso di linguaggio inappropriato o altri comportamenti considerati non professionali o non graditi nella comunità.

**Conseguenza**: Un avvertimento privato e scritto da parte dei leader della comunità, che chiarisce la natura della violazione e spiega perché il comportamento era inappropriato. Potrebbe essere richiesta una scusa pubblica.

### 2. Avviso

**Impatto sulla comunità**: Una violazione attraverso un singolo incidente o una serie di azioni.

**Conseguenza**: Un avvertimento con conseguenze per comportamenti continuativi. Nessuna interazione con le persone coinvolte, inclusa l'interazione non richiesta con coloro che fanno rispettare il Codice di Condotta, per un periodo di tempo specificato. Ciò include l'evitare interazioni negli spazi della comunità così come nei canali esterni come i social media. La violazione di questi termini può portare a un ban temporaneo o permanente.

### 3. Sospensione temporanea

**Impatto sulla comunità**: Una grave violazione degli standard della comunità, inclusi comportamenti inappropriati prolungati.

**Conseguenza**: Un ban temporaneo da qualsiasi tipo di interazione o comunicazione pubblica con la comunità per un periodo di tempo specificato. Durante questo periodo non è consentito alcun interazione pubblica o privata con le persone coinvolte, inclusa l'interazione non richiesta con coloro che fanno rispettare il Codice di Condotta. La violazione di questi termini può portare a un ban permanente.

### 4. Divieto permanente

**Impatto sulla comunità**: Dimostrazione di un modello di violazione degli standard della comunità, inclusi comportamenti inappropriati persistenti, molestie nei confronti di un individuo o aggressione o denigrazione di classi di individui.

**Conseguenza**: Un ban permanente da qualsiasi tipo di interazione pubblica all'interno della comunità.

## Attribuzione

Questo Codice di Condotta è adattato dal [Contributor Covenant][homepage],  
versione 2.0, disponibile all'indirizzo  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.  

Le Linee guida sull'impatto nella Comunità sono state ispirate dalla [scala di applicazione del codice di condotta di Mozilla](https://github.com/mozilla/diversity).  

[homepage]: https://www.contributor-covenant.org  

Per risposte alle domande frequenti su questo codice di condotta, consulta le [Domande frequenti](#domande-frequenti) all'indirizzo  
https://www.contributor-covenant.org/faq. Le traduzioni sono disponibili su  
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>